@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from __future__ import annotations
 
 import argparse
 import asyncio
@@ -32,32 +33,19 @@ import httpx
 import rich
 import rich.console
 
+from mergify_cli import github_types
+
 
 VERSION = importlib.metadata.version("mergify-cli")
 
 CHANGEID_RE = re.compile(r"Change-Id: (I[0-9a-z]{40})")
 DEPENDS_ON_RE = re.compile(r"Depends-On: (#[0-9]*)")
-READY_FOR_REVIEW_TEMPLATE = 'mutation { markPullRequestReadyForReview(input: { pullRequestId: "%s" }) { clientMutationId } }'
-DRAFT_TEMPLATE = 'mutation { convertPullRequestToDraft(input: { pullRequestId: "%s" }) { clientMutationId } }'
 console = rich.console.Console(log_path=False, log_time=False)
 
 DEBUG = False
 TMP_STACK_BRANCH = "mergify-cli-tmp"
 
 
-def check_for_graphql_errors(response: httpx.Response) -> None:
-    data = response.json()
-    if "errors" in data:
-        console.print(f"url: {response.request.url}", style="red")
-        console.print(f"data: {response.request.content.decode()}", style="red")
-        if "errors" in data:
-            console.print(
-                "\n".join(f"* {e.get('message') or e}" for e in data["errors"]),
-                style="red",
-            )
-        sys.exit(1)
-
-
 def check_for_status(response: httpx.Response) -> None:
     if response.status_code < 400:
         return
@@ -118,12 +106,11 @@ def get_slug(url: str) -> tuple[str, str]:
         path = parsed.path[1:].rstrip("/")
 
     user, repo = path.split("/", 1)
-    if repo.endswith(".git"):
-        repo = repo[:-4]
+    repo = repo.removesuffix(".git")
     return user, repo
 
 
-async def do_setup() -> None:
+async def stack_setup(_: argparse.Namespace) -> None:
     hooks_dir = pathlib.Path(await git("rev-parse", "--git-path", "hooks"))
     installed_hook_file = hooks_dir / "commit-msg"
 
@@ -133,10 +120,12 @@ async def do_setup() -> None:
 
     if installed_hook_file.exists():
         async with aiofiles.open(installed_hook_file) as f:
-            data_installed = f.read()
+            data_installed = await f.read()
         async with aiofiles.open(new_hook_file) as f:
-            data_new = f.read()
-        if data_installed != data_new:
+            data_new = await f.read()
+        if data_installed == data_new:
+            console.log("Git commit-msg hook is up to date")
+        else:
             console.print(
                 f"error: {installed_hook_file} differ from mergify_cli hook",
                 style="red",
@@ -149,52 +138,38 @@ async def do_setup() -> None:
         installed_hook_file.chmod(0o755)
 
 
-class GitRef(typing.TypedDict):
-    ref: str
-
-
-class HeadRef(typing.TypedDict):
-    sha: str
-
-
-class PullRequest(typing.TypedDict):
-    html_url: str
-    number: str
-    title: str
-    body: str
-    head: HeadRef
-    state: str
-    draft: bool
-    node_id: str
-
-
-class Comment(typing.TypedDict):
-    body: str
-    url: str
-
-
 ChangeId = typing.NewType("ChangeId", str)
-KnownChangeIDs = typing.NewType("KnownChangeIDs", dict[ChangeId, PullRequest | None])
+KnownChangeIDs = typing.NewType(
+    "KnownChangeIDs",
+    dict[ChangeId, github_types.PullRequest | None],
+)
 
 
 async def get_changeid_and_pull(
     client: httpx.AsyncClient,
     user: str,
     stack_prefix: str,
-    ref: GitRef,
-) -> tuple[ChangeId, PullRequest | None]:
+    ref: github_types.GitRef,
+) -> tuple[ChangeId, github_types.PullRequest | None]:
     branch = ref["ref"][len("refs/heads/") :]
     changeid = ChangeId(branch[len(stack_prefix) + 1 :])
     r = await client.get("pulls", params={"head": f"{user}:{branch}", "state": "open"})
     check_for_status(r)
     pulls = [
-        p for p in typing.cast(list[PullRequest], r.json()) if p["state"] == "open"
+        p
+        for p in typing.cast(list[github_types.PullRequest], r.json())
+        if p["state"] == "open"
     ]
     if len(pulls) > 1:
         msg = f"More than 1 pull found with this head: {branch}"
         raise RuntimeError(msg)
     if pulls:
-        return changeid, pulls[0]
+        pull = pulls[0]
+        if pull["body"] is None:
+            r = await client.get(f"pulls/{pull['number']}")
+            check_for_status(r)
+            pull = typing.cast(github_types.PullRequest, r.json())
+        return changeid, pull
     return changeid, None
 
 
@@ -206,11 +181,12 @@ async def get_local_changes(
     stack_prefix: str,
     known_changeids: KnownChangeIDs,
     create_as_draft: bool,
+    only_update_existing_pulls: bool,
 ) -> list[Change]:
     changes = []
     for commit in commits:
-        message = await git("log", "-1", "--format='%b'", commit)
-        title = await git("log", "-1", "--format='%s'", commit)
+        message = await git("log", "-1", "--format=%b", commit)
+        title = await git("log", "-1", "--format=%s", commit)
         changeids = CHANGEID_RE.findall(message)
         if not changeids:
             console.print(
@@ -221,33 +197,49 @@ async def get_local_changes(
                 "Did you run `mergify stack --setup` for this repository?",
             )
             sys.exit(1)
+
         changeid = ChangeId(changeids[-1])
         changes.append(Change((changeid, commit, title, message)))
         pull = known_changeids.get(changeid)
-        draft = ""
+
+        url: str = ""
+        draft: str = ""
+        action: str
+        commit_info: str
         if pull is None:
-            action = "to create"
-            if create_as_draft:
-                draft = " [yellow](draft)[/]"
-            url = f"<{stack_prefix}/{changeid}>"
             commit_info = commit[-7:]
+
+            if only_update_existing_pulls:
+                action = "nothing (to create, only updating)"
+            else:
+                action = "to create"
+                url = f"<{stack_prefix}/{changeid}>"
+
+                if create_as_draft:
+                    draft = " [yellow](draft)[/]"
+
         else:
             url = pull["html_url"]
             head_commit = commit[-7:]
             commit_info = head_commit
+
             if pull["head"]["sha"][-7:] != head_commit:
                 action = "to update"
-                commit_info = f"{pull['head']['sha'][-7:]} -> {head_commit}"
+                commit_info = f"{pull['head']['sha'][:7]} -> {head_commit}"
             else:
                 action = "nothing"
 
-            draft = ""
             if pull["draft"]:
                 draft = " [yellow](draft)[/]"
 
-        console.log(
-            f"* [yellow]\\[{action}][/] '[red]{commit_info}[/] - [b]{title}[/]{draft} {url} - {changeid}",
+        log_message = (
+            f"* [yellow]\\[{action}][/] '[red]{commit_info}[/] - [b]{title}[/]{draft}"
         )
+        if url:
+            log_message += f" {url}"
+
+        log_message += f" - {changeid}"
+        console.log(log_message)
 
     return changes
 
@@ -274,7 +266,7 @@ def get_changeids_to_delete(
 
 async def create_or_update_comments(
     client: httpx.AsyncClient,
-    pulls: list[PullRequest],
+    pulls: list[github_types.PullRequest],
 ) -> None:
     stack_comment = StackComment(pulls)
 
@@ -284,7 +276,7 @@ async def create_or_update_comments(
         r = await client.get(f"issues/{pull['number']}/comments")
         check_for_status(r)
 
-        comments = typing.cast(list[Comment], r.json())
+        comments = typing.cast(list[github_types.Comment], r.json())
         for comment in comments:
             if StackComment.is_stack_comment(comment):
                 if comment["body"] != new_body:
@@ -304,11 +296,11 @@ async def create_or_update_comments(
 
 @dataclasses.dataclass
 class StackComment:
-    pulls: list[PullRequest]
+    pulls: list[github_types.PullRequest]
 
     STACK_COMMENT_FIRST_LINE = "This pull request is part of a stack:\n"
 
-    def body(self, current_pull: PullRequest) -> str:
+    def body(self, current_pull: github_types.PullRequest) -> str:
         body = self.STACK_COMMENT_FIRST_LINE
 
         for pull in self.pulls:
@@ -320,7 +312,7 @@ class StackComment:
         return body
 
     @staticmethod
-    def is_stack_comment(comment: Comment) -> bool:
+    def is_stack_comment(comment: github_types.Comment) -> bool:
         return comment["body"].startswith(StackComment.STACK_COMMENT_FIRST_LINE)
 
 
@@ -333,11 +325,11 @@ async def create_or_update_stack(  # noqa: PLR0913,PLR0917
     commit: str,
     title: str,
     message: str,
-    depends_on: PullRequest | None,
+    depends_on: github_types.PullRequest | None,
     known_changeids: KnownChangeIDs,
     create_as_draft: bool,
     keep_pull_request_title_and_body: bool,
-) -> tuple[PullRequest, str]:
+) -> tuple[github_types.PullRequest, str]:
     if changeid in known_changeids:
         pull = known_changeids.get(changeid)
         status_message = f"* updating stacked branch `{stacked_dest_branch}` ({commit[-7:]}) - {pull['html_url'] if pull else '<stack branch without associated pull>'})"
@@ -371,6 +363,9 @@ async def create_or_update_stack(  # noqa: PLR0913,PLR0917
                 "base": stacked_base_branch,
             }
             if keep_pull_request_title_and_body:
+                if pull["body"] is None:
+                    msg = "GitHub returned a pull request without body set"
+                    raise RuntimeError(msg)
                 pull_changes.update(
                     {"body": format_pull_description(pull["body"], depends_on)},
                 )
@@ -400,37 +395,10 @@ async def create_or_update_stack(  # noqa: PLR0913,PLR0917
                 },
             )
             check_for_status(r)
-            pull = typing.cast(PullRequest, r.json())
+            pull = typing.cast(github_types.PullRequest, r.json())
     return pull, action
 
 
-async def check_and_update_pull_status(
-    client: httpx.AsyncClient,
-    pull: PullRequest,
-    create_as_draft: bool,
-) -> str:
-    if create_as_draft:
-        action = "draft"
-        template = DRAFT_TEMPLATE
-    else:
-        action = "ready_for_review"
-        template = READY_FOR_REVIEW_TEMPLATE
-
-    r = await client.post(
-        "https://api.github.com/graphql",
-        headers={
-            "Accept": "application/vnd.github.v4.idl",
-            "User-Agent": f"mergify_cli/{VERSION}",
-            "Authorization": client.headers["Authorization"],
-        },
-        json={"query": template % pull["node_id"]},
-    )
-    check_for_status(r)
-    check_for_graphql_errors(r)
-
-    return action
-
-
 async def delete_stack(
     client: httpx.AsyncClient,
     stack_prefix: str,
@@ -475,7 +443,7 @@ async def git_get_target_branch(branch: str) -> str:
     )
 
 
-async def git_get_remote_for_branch(branch: str) -> str:
+async def git_get_target_remote(branch: str) -> str:
     return await git("config", "--get", "branch." + branch + ".remote")
 
 
@@ -495,15 +463,16 @@ async def get_trunk() -> str:
             style="red",
         )
         raise
+
     try:
-        remote = await git_get_remote_for_branch(target_branch)
+        target_remote = await git_get_target_remote(branch_name)
     except CommandError:
         console.print(
-            f"error: can't get the remote for branch {target_branch}",
+            f"error: can't get the target remote for branch {branch_name}",
             style="red",
         )
         raise
-    return f"{remote}/{target_branch}"
+    return f"{target_remote}/{target_branch}"
 
 
 def trunk_type(trunk: str) -> tuple[str, str]:
@@ -528,9 +497,17 @@ def check_local_branch(branch_name: str, branch_prefix: str) -> None:
         raise LocalBranchInvalidError(msg)
 
 
+async def stack_edit(_: argparse.Namespace) -> None:
+    os.chdir(await git("rev-parse", "--show-toplevel"))
+    trunk = await get_trunk()
+    base = await git("merge-base", trunk, "HEAD")
+    os.execvp("git", ("git", "rebase", "-i", f"{base}^"))  # noqa: S606
+
+
 # TODO(charly): fix code to conform to linter (number of arguments, local
 # variables, statements, positional arguments, branches)
-async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
+async def stack_push(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
+    github_server: str,
     token: str,
     skip_rebase: bool,
     next_only: bool,
@@ -539,9 +516,10 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
     trunk: tuple[str, str],
     create_as_draft: bool = False,
     keep_pull_request_title_and_body: bool = False,
+    only_update_existing_pulls: bool = False,
 ) -> None:
     os.chdir(await git("rev-parse", "--show-toplevel"))
-    dest_branch = await git("rev-parse", "--abbrev-ref", "HEAD")
+    dest_branch = await git_get_branch_name()
 
     try:
         check_local_branch(branch_name=dest_branch, branch_prefix=branch_prefix)
@@ -584,7 +562,7 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
         commit
         for commit in reversed(
             (
-                await git("log", "--format='%H'", f"{base_commit_sha}..{dest_branch}")
+                await git("log", "--format=%H", f"{base_commit_sha}..{dest_branch}")
             ).split(
                 "\n",
             ),
@@ -600,7 +578,7 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
         event_hooks = {}
 
     async with httpx.AsyncClient(
-        base_url=f"https://api.github.com/repos/{user}/{repo}/",
+        base_url=f"{github_server}/repos/{user}/{repo}/",
         headers={
             "Accept": "application/vnd.github.v3+json",
             "User-Agent": f"mergify_cli/{VERSION}",
@@ -608,11 +586,12 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
         },
         event_hooks=event_hooks,  # type: ignore[arg-type]
         follow_redirects=True,
+        timeout=5.0,
     ) as client:
         with console.status("Retrieving latest pushed stacks"):
             r = await client.get(f"git/matching-refs/heads/{stack_prefix}/")
             check_for_status(r)
-            refs = typing.cast(list[GitRef], r.json())
+            refs = typing.cast(list[github_types.GitRef], r.json())
 
             tasks = [
                 asyncio.create_task(
@@ -634,6 +613,7 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
                 stack_prefix,
                 known_changeids,
                 create_as_draft,
+                only_update_existing_pulls,
             )
             changeids_to_delete = get_changeids_to_delete(
                 changes,
@@ -644,14 +624,18 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
             console.log("[orange]Finished (dry-run mode) :tada:[/]")
             sys.exit(0)
 
-        console.log("New stacked pull request:", style="green")
+        console.log("Updating and/or creating stacked pull requests:", style="green")
         stacked_base_branch = base_branch
-        pulls: list[PullRequest] = []
+        pulls: list[github_types.PullRequest] = []
         continue_create_or_update = True
         for changeid, commit, title, message in changes:
+            pull: github_types.PullRequest | None = None
             depends_on = pulls[-1] if pulls else None
             stacked_dest_branch = f"{stack_prefix}/{changeid}"
-            if continue_create_or_update:
+            if only_update_existing_pulls and changeid not in known_changeids:
+                action = "skipped, only rebasing"
+
+            elif continue_create_or_update:
                 pull, action = await create_or_update_stack(
                     client,
                     remote,
@@ -669,7 +653,7 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
                 pulls.append(pull)
             else:
                 action = "skipped"
-                pull = known_changeids.get(changeid) or PullRequest(
+                pull = known_changeids.get(changeid) or github_types.PullRequest(
                     {
                         "title": "<not yet created>",
                         "body": "<not yet created>",
@@ -681,19 +665,25 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
                         "head": {"sha": ""},
                     },
                 )
-            draft = ""
-            if pull["draft"]:
-                draft = " [yellow](draft)[/]"
 
-            console.log(
-                f"* [blue]\\[{action}][/] '[red]{commit[-7:]}[/] - [b]{pull['title']}[/]{draft} {pull['html_url']} - {changeid}",
-            )
+            log_message = f"* [blue]\\[{action}][/] '[red]{commit[-7:]}[/]"
+            if pull is not None:
+                log_message += f" - [b]{pull['title']}[/]"
+                if pull["draft"]:
+                    log_message += " [yellow](draft)[/]"
+
+                log_message += f" {pull['html_url']}"
+
+            log_message += f" - {changeid}"
+            console.log(log_message)
+
             stacked_base_branch = stacked_dest_branch
             if continue_create_or_update and next_only:
                 continue_create_or_update = False
 
         with console.status("Updating comments..."):
             await create_or_update_comments(client, pulls)
+
         console.log("[green]Comments updated")
 
         with console.status("Deleting unused branches..."):
@@ -709,7 +699,10 @@ async def stack(  # noqa: PLR0913, PLR0914, PLR0915, PLR0917, PLR0912
         console.log("[green]Finished :tada:[/]")
 
 
-def format_pull_description(message: str, depends_on: PullRequest | None) -> str:
+def format_pull_description(
+    message: str,
+    depends_on: github_types.PullRequest | None,
+) -> str:
     depends_on_header = ""
     if depends_on is not None:
         depends_on_header = f"\n\nDepends-On: #{depends_on['number']}"
@@ -726,6 +719,22 @@ def GitHubToken(v: str) -> str:  # noqa: N802
     return v
 
 
+async def get_default_github_server() -> str:
+    try:
+        result = await git("config", "--get", "mergify-cli.github-server")
+    except CommandError:
+        result = ""
+
+    url = parse.urlparse(result or "https://api.github.com/")
+    url = url._replace(scheme="https")
+
+    if url.hostname == "api.github.com":
+        url = url._replace(path="")
+    else:
+        url = url._replace(path="/api/v3")
+    return url.geturl()
+
+
 async def get_default_branch_prefix() -> str:
     try:
         result = await git("config", "--get", "mergify-cli.stack-branch-prefix")
@@ -759,12 +768,14 @@ async def get_default_token() -> str:
     return token
 
 
-async def stack_main(args: argparse.Namespace) -> None:
+async def _stack_push(args: argparse.Namespace) -> None:
     if args.setup:
-        await do_setup()
+        # backward compat
+        await stack_setup(args)
         return
 
-    await stack(
+    await stack_push(
+        args.github_server,
         args.token,
         args.skip_rebase,
         args.next_only,
@@ -773,6 +784,99 @@ async def stack_main(args: argparse.Namespace) -> None:
         args.trunk,
         args.draft,
         args.keep_pull_request_title_and_body,
+        args.only_update_existing_pulls,
+    )
+
+
+def register_stack_setup_parser(
+    sub_parsers: argparse._SubParsersAction[typing.Any],
+) -> None:
+    parser = sub_parsers.add_parser(
+        "setup",
+        description="Configure the git hooks",
+        help="Initial installation of the required git commit-msg hook",
+    )
+    parser.set_defaults(func=stack_setup)
+
+
+def register_stack_edit_parser(
+    sub_parsers: argparse._SubParsersAction[typing.Any],
+) -> None:
+    parser = sub_parsers.add_parser(
+        "edit",
+        description="Edit the stack history",
+        help="Edit the stack history",
+    )
+    parser.set_defaults(func=stack_edit)
+
+
+async def register_stack_push_parser(
+    sub_parsers: argparse._SubParsersAction[typing.Any],
+) -> None:
+    parser = sub_parsers.add_parser(
+        "push",
+        description="Push/sync the pull requests stack",
+        help="Push/sync the pull requests stack",
+    )
+    parser.set_defaults(func=_stack_push)
+
+    # Backward compat
+    parser.add_argument(
+        "--setup",
+        action="store_true",
+        help="Initial installation of the required git commit-msg hook",
+    )
+
+    parser.add_argument(
+        "--dry-run",
+        "-n",
+        action="store_true",
+        help="Only show what is going to be done",
+    )
+    parser.add_argument(
+        "--next-only",
+        "-x",
+        action="store_true",
+        help="Only rebase and update the next pull request of the stack",
+    )
+    parser.add_argument(
+        "--skip-rebase",
+        "-R",
+        action="store_true",
+        help="Skip stack rebase",
+    )
+    parser.add_argument(
+        "--draft",
+        "-d",
+        action="store_true",
+        help="Create stacked pull request as draft",
+    )
+    parser.add_argument(
+        "--keep-pull-request-title-and-body",
+        "-k",
+        action="store_true",
+        default=await get_default_keep_pr_title_body(),
+        help="Don't update the title and body of already opened pull requests. "
+        "Default fetched from git config if added with `git config --add mergify-cli.stack-keep-pr-title-body true`",
+    )
+    parser.add_argument(
+        "--trunk",
+        "-t",
+        type=trunk_type,
+        default=await get_trunk(),
+        help="Change the target branch of the stack.",
+    )
+    parser.add_argument(
+        "--branch-prefix",
+        default=await get_default_branch_prefix(),
+        help="Branch prefix used to create stacked PR. "
+        "Default fetched from git config if added with `git config --add mergify-cli.stack-branch-prefix some-prefix`",
+    )
+    parser.add_argument(
+        "--only-update-existing-pulls",
+        "-u",
+        action="store_true",
+        help="Only update existing pull requests, do not create new ones",
     )
 
 
@@ -793,6 +897,12 @@ async def parse_args(args: typing.MutableSequence[str]) -> argparse.Namespace:
         help="GitHub personal access token",
     )
     parser.add_argument("--dry-run", "-n", action="store_true")
+    parser.add_argument(
+        "--github-server",
+        action="store_true",
+        default=await get_default_github_server(),
+    )
+
     sub_parsers = parser.add_subparsers(dest="action")
 
     stack_parser = sub_parsers.add_parser(
@@ -800,61 +910,21 @@ async def parse_args(args: typing.MutableSequence[str]) -> argparse.Namespace:
         description="Stacked Pull Requests CLI",
         help="Create a pull requests stack",
     )
-    stack_parser.set_defaults(func=stack_main)
-    stack_parser.add_argument(
-        "--setup",
-        action="store_true",
-        help="Initial installation of the required git commit-msg hook",
-    )
-    stack_parser.add_argument(
-        "--dry-run",
-        "-n",
-        action="store_true",
-        help="Only show what is going to be done",
-    )
-    stack_parser.add_argument(
-        "--next-only",
-        "-x",
-        action="store_true",
-        help="Only rebase and update the next pull request of the stack",
-    )
-    stack_parser.add_argument(
-        "--skip-rebase",
-        "-R",
-        action="store_true",
-        help="Skip stack rebase",
-    )
-    stack_parser.add_argument(
-        "--draft",
-        "-d",
-        action="store_true",
-        help="Create stacked pull request as draft",
-    )
-    stack_parser.add_argument(
-        "--keep-pull-request-title-and-body",
-        "-k",
-        action="store_true",
-        default=await get_default_keep_pr_title_body(),
-        help="Don't update the title and body of already opened pull requests. "
-        "Default fetched from git config if added with `git config --add mergify-cli.stack-keep-pr-title-body true`",
-    )
-    stack_parser.add_argument(
-        "--trunk",
-        "-t",
-        type=trunk_type,
-        default=await get_trunk(),
-        help="Change the target branch of the stack.",
-    )
-    stack_parser.add_argument(
-        "--branch-prefix",
-        default=await get_default_branch_prefix(),
-        help="Branch prefix used to create stacked PR. "
-        "Default fetched from git config if added with `git config --add mergify-cli.stack-branch-prefix some-prefix`",
-    )
+    stack_sub_parsers = stack_parser.add_subparsers(dest="stack_action")
+    await register_stack_push_parser(stack_sub_parsers)
+    register_stack_edit_parser(stack_sub_parsers)
+    register_stack_setup_parser(stack_sub_parsers)
 
     known_args, _ = parser.parse_known_args(args)
+
+    # Default
     if known_args.action is None:
-        args.insert(1, "stack")
+        args.insert(0, "stack")
+
+    known_args, _ = parser.parse_known_args(args)
+
+    if known_args.action == "stack" and known_args.stack_action is None:
+        args.insert(1, "push")
 
     return parser.parse_args(args)
 
