@@ -26,6 +26,13 @@ import mergify_cli
 from mergify_cli.tests import utils as test_utils
 
 
+@pytest.fixture(autouse=True)
+def _unset_github_token(
+    monkeypatch: pytest.MonkeyPatch,
+) -> None:
+    monkeypatch.setenv("GITHUB_TOKEN", "whatever")
+
+
 @pytest.fixture(autouse=True)
 def _change_working_directory(
     monkeypatch: pytest.MonkeyPatch,
@@ -36,7 +43,7 @@ def _change_working_directory(
     monkeypatch.chdir(tmp_path)
 
 
-@pytest.fixture()
+@pytest.fixture
 def _git_repo() -> None:
     subprocess.call(["git", "init", "--initial-branch=main"])
     subprocess.call(["git", "config", "user.email", "test@example.com"])
@@ -46,7 +53,7 @@ def _git_repo() -> None:
     subprocess.call(["git", "config", "--add", "branch.main.remote", "origin"])
 
 
-@pytest.fixture()
+@pytest.fixture
 def git_mock(
     tmp_path: pathlib.Path,
 ) -> typing.Generator[test_utils.GitMock, None, None]:
@@ -98,8 +105,8 @@ async def test_get_target_branch() -> None:
 
 
 @pytest.mark.usefixtures("_git_repo")
-async def test_get_remote_for_branch() -> None:
-    assert await mergify_cli.git_get_remote_for_branch("main") == "origin"
+async def test_get_target_remote() -> None:
+    assert await mergify_cli.git_get_target_remote("main") == "origin"
 
 
 @pytest.mark.usefixtures("_git_repo")
@@ -201,7 +208,8 @@ async def test_stack_create(
         200,
     )
 
-    await mergify_cli.stack(
+    await mergify_cli.stack_push(
+        github_server="https://api.github.com/",
         token="",
         skip_rebase=False,
         next_only=False,
@@ -288,7 +296,8 @@ async def test_stack_create_single_pull(
     )
     respx_mock.get("/repos/user/repo/issues/1/comments").respond(200, json=[])
 
-    await mergify_cli.stack(
+    await mergify_cli.stack_push(
+        github_server="https://api.github.com/",
         token="",
         skip_rebase=False,
         next_only=False,
@@ -343,6 +352,7 @@ async def test_stack_update_no_rebase(
                 "number": "123",
                 "title": "Title",
                 "head": {"sha": "previous_commit_sha"},
+                "body": "body",
                 "state": "open",
                 "draft": False,
                 "node_id": "",
@@ -364,7 +374,8 @@ async def test_stack_update_no_rebase(
     )
     respx_mock.patch("/repos/user/repo/issues/comments/456").respond(200)
 
-    await mergify_cli.stack(
+    await mergify_cli.stack_push(
+        github_server="https://api.github.com/",
         token="",
         skip_rebase=True,
         next_only=False,
@@ -419,6 +430,7 @@ async def test_stack_update(
                 "number": "123",
                 "title": "Title",
                 "head": {"sha": "previous_commit_sha"},
+                "body": "body",
                 "state": "open",
                 "draft": False,
                 "node_id": "",
@@ -440,7 +452,8 @@ async def test_stack_update(
     )
     respx_mock.patch("/repos/user/repo/issues/comments/456").respond(200)
 
-    await mergify_cli.stack(
+    await mergify_cli.stack_push(
+        github_server="https://api.github.com/",
         token="",
         skip_rebase=False,
         next_only=False,
@@ -517,7 +530,8 @@ async def test_stack_update_keep_title_and_body(
     )
     respx_mock.patch("/repos/user/repo/issues/comments/456").respond(200)
 
-    await mergify_cli.stack(
+    await mergify_cli.stack_push(
+        github_server="https://api.github.com/",
         token="",
         skip_rebase=False,
         next_only=False,
@@ -543,7 +557,8 @@ async def test_stack_on_destination_branch_raises_an_error(
     git_mock.mock("rev-parse", "--abbrev-ref", "HEAD", output="main")
 
     with pytest.raises(SystemExit, match="1"):
-        await mergify_cli.stack(
+        await mergify_cli.stack_push(
+            github_server="https://api.github.com/",
             token="",
             skip_rebase=False,
             next_only=False,
@@ -560,7 +575,8 @@ async def test_stack_without_common_commit_raises_an_error(
     git_mock.mock("merge-base", "--fork-point", "origin/main", output="")
 
     with pytest.raises(SystemExit, match="1"):
-        await mergify_cli.stack(
+        await mergify_cli.stack_push(
+            github_server="https://api.github.com/",
             token="",
             skip_rebase=False,
             next_only=False,
@@ -587,3 +603,31 @@ async def test_defaults_config_args_set(
 ) -> None:
     with mock.patch.object(mergify_cli, "_run_command", return_value=config_get_result):
         assert (await default_arg_fct()) == expected_default
+
+
+@pytest.mark.parametrize(
+    "args",
+    [
+        ["-R"],
+        ["stack", "-R"],
+        ["stack", "push", "-R"],
+    ],
+)
+async def test_default(
+    git_mock: test_utils.GitMock,
+    args: list[str],
+) -> None:
+    git_mock.default_cli_args()
+    parsed = await mergify_cli.parse_args(args)
+    assert parsed.action == "stack"
+    assert parsed.stack_action == "push"
+    assert parsed.skip_rebase
+
+
+async def test_parse_edit(
+    git_mock: test_utils.GitMock,
+) -> None:
+    git_mock.default_cli_args()
+    parsed = await mergify_cli.parse_args(["stack", "edit"])
+    assert parsed.action == "stack"
+    assert parsed.stack_action == "edit"
